setStay method
Sets the stay option flag
When true, adds -stay argument to keep the launcher open after Minecraft closes
Implementation
void setStay(bool value) {
_stay = value;
}
Sets the stay option flag
When true, adds -stay argument to keep the launcher open after Minecraft closes
void setStay(bool value) {
_stay = value;
}