LauncherOptions class
Class that defines launch options for HeadlessMC.
Constructors
- LauncherOptions({required String version, bool lwjgl = false, bool noOutput = false, bool specifics = false, bool commands = false, bool inMemory = false, bool jndi = false, bool lookup = false, bool paulscode = false, bool offline = false, bool keep = false, String? jvmArgs, String? gameArgs, int retries = 0, String? username, Directory? workingDirectory})
- Constructor
Properties
- commands ↔ bool
-
Whether to enable headlessmc-runtime
getter/setter pair
- gameArgs ↔ String?
-
Game arguments
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inMemory ↔ bool
-
Whether to launch the game in memory (same JVM)
getter/setter pair
- jndi ↔ bool
-
Whether to patch Log4J JNDI lookups
getter/setter pair
- jvmArgs ↔ String?
-
JVM arguments
getter/setter pair
- keep ↔ bool
-
Whether to keep files used to launch Minecraft without deleting them
getter/setter pair
- lookup ↔ bool
-
Whether to patch all Log4J lookups
getter/setter pair
- lwjgl ↔ bool
-
Whether to launch in headless mode (without GUI)
getter/setter pair
- noOutput ↔ bool
-
Whether to disable Minecraft output
getter/setter pair
- offline ↔ bool
-
Whether to use an offline account (headless mode is automatically enabled)
getter/setter pair
- paulscode ↔ bool
-
Whether to patch paulscode sound library which causes annoying log output in headless mode
getter/setter pair
- retries ↔ int
-
Number of retries
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specifics ↔ bool
-
Whether to automatically download hmc-specifics for the version
getter/setter pair
- username ↔ String?
-
Logged in username
getter/setter pair
- version → String
-
Minecraft version or version with modloader (e.g. "1.21.2" or "forge:1.21.2")
final
- workingDirectory ↔ Directory?
-
Working directory
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCommandLineArgs(
) → List< String> - Generate a list of command line arguments
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited