InteractiveStreamManager class

Class for managing interactive command-line processes with bidirectional communication

Constructors

InteractiveStreamManager(Process _process, {int responseTimeoutMs = 5000})
Creates a new interactive stream manager for a process

Properties

hashCode int
The hash code for this object.
no setterinherited
outputBuffer List<String>
Get all collected output
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderrStream Stream<String>
Get a stream of error output
no setter
stdoutStream Stream<String>
Get a stream of standard output
no setter

Methods

clearOutputBuffer() → void
Clear the output buffer
dispose() → void
Dispose and clean up resources
handleDebugConsoleInput(String input) Future<bool>
Handle input from VSCode debug console
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendCommand(String command, {bool endCondition(String)?, int? customTimeoutMs}) Future<List<String>>
Send a command to the process
setupDefaultOutputHandlers() → void
Set up default output handlers to print standard output and error streams This creates additional listeners that will always output to debugPrint regardless of other subscriptions
toString() String
A string representation of this object.
inherited
waitForOutput(String content, {bool caseSensitive = true, int timeoutMs = 10000}) Future<bool>
Wait for specific content to appear in the output

Operators

operator ==(Object other) bool
The equality operator.
inherited