EnvironmentVariableManager class

A class to manage environment variables across different platforms

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEnvironmentVariable(String key, String value) → void
Adds an environment variable to the current process
getAllEnvironmentVariables() Map<String, String>
Gets all environment variables
getEnvironmentVariable(String key) String?
Retrieves the value of an environment variable
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEnvironmentVariable(String key) → void
Removes an environment variable from the current process Only affects the in-memory copy of environment variables
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited