JavaOptions class

Constructors

JavaOptions()
Creates a new JavaOptions instance with default settings
JavaOptions.withDefaults({String? initialMemory, String? maxMemory, String? gameDir, String? mcDir})
Creates a new JavaOptions instance with custom parameters
factory

Properties

arguments List<String>
no setter
gameDir String?
Gets the custom Minecraft game directory
no setter
hashCode int
The hash code for this object.
no setterinherited
initialMemory String?
Gets the initial Java heap size
no setter
jvmOptions List<String>
no setter
maxMemory String?
Gets the maximum Java heap size
no setter
mcDir String?
Gets the custom Minecraft libraries directory
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stay bool
Gets the current stay option value
no setter
systemProperties Map<String, String>
no setter

Methods

addArgument(String arg) → void
Adds a regular command line argument
addCommand(String command, String value) → void
Adds a command to the arguments
addJvmOption(String option) → void
Adds a JVM option (-X option)
copy() JavaOptions
Creates a copy of this options object
getSystemProperty(String key) String?
Gets a system property value
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeJvmOption(String option) → void
Removes a JVM option
removeSystemProperty(String key) → void
Removes a system property
setGameDir(String path) → void
Sets the custom Minecraft game directory
setInitialMemory(String value) → void
Sets the initial Java heap size
setMaxMemory(String value) → void
Sets the maximum Java heap size
setMcDir(String path) → void
Sets the custom Minecraft libraries directory
setStay(bool value) → void
Sets the stay option flag
setSystemProperty(String key, String value) → void
Sets a system property (-D option)
toArgumentList() List<String>
Converts all options to a list of command line arguments
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited