handleDebugConsoleInput method
Handle input from VSCode debug console
Process the input from the debug console and send it to the process
Implementation
Future<bool> handleDebugConsoleInput(String input) async {
try {
// Add a newline if not present to ensure command execution
if (!input.endsWith('\n')) {
input = '$input\n';
}
// Send the input to the process
_process.stdin.write(input);
await _process.stdin.flush();
return true;
} catch (e) {
return false;
}
}