ProcessManager class
Class for managing external processes
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
killProcess(
Process process, [ProcessSignal signal = ProcessSignal.sigterm]) → bool - Kill a running process
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runProcess(
String executable, List< String> arguments, {String? workingDirectory, Map<String, String> ? environment, bool includeParentEnvironment = true, bool runInShell = false, Encoding stdoutEncoding = systemEncoding, Encoding stderrEncoding = systemEncoding}) → Future<ProcessResult> - Run a process and return its exit code and output
-
startProcess(
String executable, List< String> arguments, {String? workingDirectory, Map<String, String> ? environment, bool includeParentEnvironment = true, bool runInShell = false, ProcessStartMode mode = ProcessStartMode.normal}) → Future<Process> - Start a process with the given executable and arguments
-
streamErrorOutput(
Process process, void onData(String)) → StreamSubscription< String> - Stream error output from a process
-
streamOutput(
Process process, void onData(String)) → StreamSubscription< String> - Stream output from a process
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited